import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["inputId", "className", "children", "icon", "iconsPosition", "clear", "isDropdown", "isLoading", "isInvalid", "isDisabled", "readOnly", "compressed", "prepend", "append", "fullWidth"];
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0 and the Server Side Public License, v 1; you may not use this file except
 * in compliance with, at your election, the Elastic License 2.0 or the Server
 * Side Public License, v 1.
 */

import React, { cloneElement, useCallback, useMemo } from 'react';
import classNames from 'classnames';
import { getIconAffordanceStyles, isRightSideIcon } from './_num_icons';
import { EuiFormControlLayoutIcons } from './form_control_layout_icons';
import { EuiFormLabel } from '../form_label';
import { useFormContext } from '../eui_form_context';
import { jsx as ___EmotionJSX } from "@emotion/react";
export var EuiFormControlLayout = function EuiFormControlLayout(props) {
  var _useFormContext = useFormContext(),
    defaultFullWidth = _useFormContext.defaultFullWidth;
  var inputId = props.inputId,
    className = props.className,
    children = props.children,
    icon = props.icon,
    _props$iconsPosition = props.iconsPosition,
    iconsPosition = _props$iconsPosition === void 0 ? 'absolute' : _props$iconsPosition,
    clear = props.clear,
    isDropdown = props.isDropdown,
    isLoading = props.isLoading,
    isInvalid = props.isInvalid,
    isDisabled = props.isDisabled,
    readOnly = props.readOnly,
    compressed = props.compressed,
    prepend = props.prepend,
    append = props.append,
    _props$fullWidth = props.fullWidth,
    fullWidth = _props$fullWidth === void 0 ? defaultFullWidth : _props$fullWidth,
    rest = _objectWithoutProperties(props, _excluded);
  var classes = classNames('euiFormControlLayout', {
    'euiFormControlLayout--fullWidth': fullWidth,
    'euiFormControlLayout--compressed': compressed,
    'euiFormControlLayout--readOnly': readOnly,
    'euiFormControlLayout--group': prepend || append,
    'euiFormControlLayout-isDisabled': isDisabled
  }, className);
  var hasDropdownIcon = !readOnly && !isDisabled && isDropdown;
  var hasRightIcon = isRightSideIcon(icon);
  var hasLeftIcon = icon && !hasRightIcon;
  var hasRightIcons = hasRightIcon || clear || isLoading || isInvalid || hasDropdownIcon;
  var iconAffordanceStyles = useMemo(function () {
    if (iconsPosition === 'static') return; // Static icons don't need padding affordance

    return getIconAffordanceStyles({
      icon: icon,
      clear: clear,
      isInvalid: isInvalid,
      isLoading: isLoading,
      isDropdown: hasDropdownIcon
    });
  }, [iconsPosition, icon, clear, isInvalid, isLoading, hasDropdownIcon]);
  return ___EmotionJSX("div", _extends({
    className: classes
  }, rest), ___EmotionJSX(EuiFormControlLayoutSideNodes, {
    side: "prepend",
    nodes: prepend,
    inputId: inputId
  }), ___EmotionJSX("div", {
    className: "euiFormControlLayout__childrenWrapper",
    style: iconAffordanceStyles
  }, hasLeftIcon && ___EmotionJSX(EuiFormControlLayoutIcons, {
    side: "left",
    icon: icon,
    iconsPosition: iconsPosition,
    compressed: compressed
  }), children, hasRightIcons && ___EmotionJSX(EuiFormControlLayoutIcons, {
    side: "right",
    icon: hasRightIcon ? icon : undefined,
    iconsPosition: iconsPosition,
    compressed: compressed,
    clear: clear,
    isLoading: isLoading,
    isInvalid: isInvalid,
    isDropdown: hasDropdownIcon
  })), ___EmotionJSX(EuiFormControlLayoutSideNodes, {
    side: "append",
    nodes: append,
    inputId: inputId
  }));
};

/**
 * Internal subcomponent utility for prepend/append nodes
 */
var EuiFormControlLayoutSideNodes = function EuiFormControlLayoutSideNodes(_ref) {
  var side = _ref.side,
    nodes = _ref.nodes,
    inputId = _ref.inputId;
  var className = "euiFormControlLayout__".concat(side);
  var renderFormLabel = useCallback(function (label) {
    return ___EmotionJSX(EuiFormLabel, {
      htmlFor: inputId,
      className: className
    }, label);
  }, [inputId, className]);
  if (!nodes) return null;
  return ___EmotionJSX(React.Fragment, null, React.Children.map(nodes, function (node, index) {
    return typeof node === 'string' ? renderFormLabel(node) : /*#__PURE__*/cloneElement(node, {
      className: classNames(className, node.props.className),
      key: index
    });
  }));
};