"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.isRightSideIcon = exports.getIconAffordanceStyles = exports.getFormControlClassNameForIconCount = void 0;
var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));
var _form_control_layout_icons = require("./form_control_layout_icons");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0 and the Server Side Public License, v 1; you may not use this file except
 * in compliance with, at your election, the Elastic License 2.0 or the Server
 * Side Public License, v 1.
 */

/**
 * The `getFormControlClassNameForIconCount` function helps setup the className appendum
 * depending on the form control's current settings/state.
 *
 * @param icon {boolean} Does it contain a static icon like arrowDown
 * @param clear {boolean} Is it currently clearable
 * @param isLoading {boolean} Is is currently loading
 * @param isInvalid {boolean} It is currently invalid
 * @param isDropdown {boolean} It is as dropdown
 * @returns {string | undefined} Returns the string to append to the base className of the form control; or `undefined` if all evaluate to false
 */

var getFormControlClassNameForIconCount = exports.getFormControlClassNameForIconCount = function getFormControlClassNameForIconCount(_ref) {
  var icon = _ref.icon,
    clear = _ref.clear,
    isLoading = _ref.isLoading,
    isInvalid = _ref.isInvalid,
    isDropdown = _ref.isDropdown;
  var numIcons = [icon, clear, isInvalid, isLoading, isDropdown].filter(function (item) {
    return item === true;
  }).length;

  // This className is also specifically used in `src/global_styling/mixins/_form.scss`
  return numIcons > 0 ? "euiFormControlLayout--".concat(numIcons, "icons") : undefined;
};
var isRightSideIcon = exports.isRightSideIcon = function isRightSideIcon(icon) {
  return !!icon && (0, _form_control_layout_icons.isIconShape)(icon) && icon.side === 'right';
};
var getIconAffordanceStyles = exports.getIconAffordanceStyles = function getIconAffordanceStyles(_ref2) {
  var icon = _ref2.icon,
    clear = _ref2.clear,
    isLoading = _ref2.isLoading,
    isInvalid = _ref2.isInvalid,
    isDropdown = _ref2.isDropdown;
  var cssVariables = {
    '--euiFormControlLeftIconsCount': 0,
    '--euiFormControlRightIconsCount': 0
  };
  if (icon) {
    if (isRightSideIcon(icon)) {
      cssVariables['--euiFormControlRightIconsCount']++;
    } else {
      cssVariables['--euiFormControlLeftIconsCount']++;
    }
  }
  if (clear) cssVariables['--euiFormControlRightIconsCount']++;
  if (isLoading) cssVariables['--euiFormControlRightIconsCount']++;
  if (isInvalid) cssVariables['--euiFormControlRightIconsCount']++;
  if (isDropdown) cssVariables['--euiFormControlRightIconsCount']++;
  var filtered = Object.entries(cssVariables).filter(function (_ref3) {
    var _ref4 = (0, _slicedToArray2.default)(_ref3, 2),
      count = _ref4[1];
    return count > 0;
  });
  return filtered.length ? Object.fromEntries(filtered) : undefined;
};